% Generate Figure 2 from:
% "Gas Spectroscopy with integrated frequency monitoring
% using self-mixing in a terahertz quantum-cascade laser",
% R. Chhantyal-Pun, A. Valavanis, J. T. Keeley, P. Rubino,
% P. Dean, L. H. Li, A. G. Davies and E. H. Linfield,
% Submitted to Opt. Lett. (2017)
%
% (c) A. Valavanis and R. Chhantyal-Pun
%     University of Leeds, 2017

% File containing the exemplar current data
filename=['..' filesep 'self-mixing' filesep '1100mTorr-full-scan' filesep ...
          'reverse' filesep 'SMSpectroscopy_549.800000mA.dat'];

% Find transmitted QCL spectrum, from self-mixing data
[freq, amp] = fftsmspec_interpolated(filename);

% Find Gaussian fitting parameters from spectral data
[f0 A fwhm r_sq] = gaussian_fit(freq, amp, 3.405, 0.01);

fprintf('Gaussian peak found at f0 = %f THz\n', f0);

% Create a high-resolution frequency scale over the desired range
% just for the purposes of generating a smooth 'fitted' curve
fplot = [3.395:0.0001:3.415];

% Generate normalised Gaussian peak using fitting parameters
amp_fitted = gaussian(fplot, f0, A, fwhm);

% Normalise the plots so we have a neater "arbitrary unit" scale
peak_amp = max(amp_fitted);
amp_fitted = amp_fitted / peak_amp;
amp        = amp        / peak_amp;

% Generate figure from data
figure % New figure
fig = gcf; % Handle to the new figure

% Set paper sizing for figure to fit in 1 column, Optics Letters
left   = 0; bottom = 0;
width  = 3; height = 2;
fig.Units = 'inches';
fig.Position = [left bottom width height];
fig.PaperUnits = 'inches';
fig.PaperPosition = [left bottom width height];
fig.PaperSize     = [width height];

% Plot raw data using black 'o' symbols
plot(freq,  amp,    'ko',...
     'LineWidth',    0.5,...
     'DisplayName', 'Exp.');

hold on

% Plot fitted Gaussian using a solid black line
plot(fplot, amp_fitted, 'k-',...
     'LineWidth',    0.5,...
     'DisplayName', 'Fitted');

legh = legend('show');
legh.FontSize  = 8;
legh.LineWidth = 0.5;

% Set axis properties
ax = gca;
ax.FontName      = 'Times New Roman';
ax.FontUnits     = 'points';
ax.FontSize      = 8;
ax.LineWidth     = 0.5;
ax.XLim          = [fplot(1) fplot(end)];
ax.XLabel.String = 'Frequency (THz)';
ax.YLabel.String = 'FFT amplitude (a.u.)';
ax.XAxis.TickLabelFormat = '%.3f';
ax.YAxis.TickLabelFormat = '%.2f';

print('figure2', '-dpdf', '-r600');
