% Generate Figure 3 from:
% "Gas Spectroscopy with integrated frequency monitoring
% using self-mixing in a terahertz quantum-cascade laser",
% R. Chhantyal-Pun, A. Valavanis, J. T. Keeley, P. Rubino,
% P. Dean, L. H. Li, A. G. Davies and E. H. Linfield,
% Submitted to Opt. Lett. (2017)
%
% (c) A. Valavanis and R. Chhantyal-Pun
%     University of Leeds, 2017

% Folders containing SM interferograms for gas, using sweeps
% in forward and reverse directions
gasfolderfwd = ['..' filesep 'self-mixing' filesep '1100mTorr-full-scan' filesep 'forward'];
gasfolderrev = ['..' filesep 'self-mixing' filesep '1100mTorr-full-scan' filesep 'reverse'];

% Folders containing SM interferograms for vacuum, using sweeps
% in forward and reverse directions
reffolderfwd = ['..' filesep 'self-mixing' filesep 'vacuum-full-scan' filesep 'forward'];
reffolderrev = ['..' filesep 'self-mixing' filesep 'vacuum-full-scan' filesep 'reverse'];

% Read spectral parameters for both stage directions, through gas
[current_gas_fwd f0_gas_fwd A_gas_fwd] = spectrum_analysis(gasfolderfwd);
[current_gas_rev f0_gas_rev A_gas_rev] = spectrum_analysis(gasfolderrev);

% Read spectral parameters for both stage directions, through vacuum
[current_ref_fwd f0_ref_fwd A_ref_fwd] = spectrum_analysis(reffolderfwd);
[current_ref_rev f0_ref_rev A_ref_rev] = spectrum_analysis(reffolderrev);

% Take the average of the forward and reverse scans to avoid any SM hysteresis effects
f0_gas = 0.5 * (f0_gas_fwd + interp1(current_gas_rev, f0_gas_rev, current_gas_fwd, 'spline'));
f0_ref = 0.5 * (f0_ref_fwd + interp1(current_ref_rev, f0_ref_rev, current_ref_fwd, 'spline'));

% Fit a linear relation to the reference data
[m, f0] = Linear_fit(current_ref_fwd, f0_ref);
f_fit = m*current_ref_fwd + f0;

% Generate figure from data
figure % New figure
fig = gcf; % Handle to the new figure

% Set paper sizing for figure to fit in 1 column, Optics Letters
left   = 0; bottom = 0;
width  = 3; height = 2;
fig.Units = 'inches';
fig.Position = [left bottom width height];
fig.PaperUnits = 'inches';
fig.PaperPosition = [left bottom width height];
fig.PaperSize     = [width height];

plot(current_gas_fwd, f0_gas, 'k-',...
     'LineWidth',    0.5,...
     'DisplayName', '1100 mTorr');

hold on;

plot(current_ref_fwd, f0_ref, 'r-',...
     'LineWidth',    0.5,...
     'DisplayName', 'Vacuum');

plot(current_ref_fwd, f_fit, 'b--',...
     'LineWidth',    0.5,...
     'DisplayName',  'Fitted');

legh = legend('show');
legh.FontSize  = 8;
legh.LineWidth = 0.5;
legh.Location  = 'southeast';

% Set axis properties
ax = gca;
ax.FontName      = 'Times New Roman';
ax.FontUnits     = 'points';
ax.FontSize      = 8;
ax.LineWidth     = 0.5;
ax.XLabel.String = 'Current (mA)';
ax.YLabel.String = 'Frequency (THz)';
ax.YAxis.TickLabelFormat = '%.4f';

print('figure3', '-dpdf', '-r600');
