% Generate Figure 4 from:
% "Gas Spectroscopy with integrated frequency monitoring
% using self-mixing in a terahertz quantum-cascade laser",
% R. Chhantyal-Pun, A. Valavanis, J. T. Keeley, P. Rubino,
% P. Dean, L. H. Li, A. G. Davies and E. H. Linfield,
% Submitted to Opt. Lett. (2017)
%
% (c) A. Valavanis and R. Chhantyal-Pun
%     University of Leeds, 2017

% Folders containing SM interferograms for gas, using sweeps
% in forward and reverse directions
gasfolderfwd = ['..' filesep 'self-mixing' filesep '1100mTorr-full-scan' filesep 'forward'];
gasfolderrev = ['..' filesep 'self-mixing' filesep '1100mTorr-full-scan' filesep 'reverse'];

% Folders containing SM interferograms for vacuum, using sweeps
% in forward and reverse directions
reffolderfwd = ['..' filesep 'self-mixing' filesep 'vacuum-full-scan' filesep 'forward'];
reffolderrev = ['..' filesep 'self-mixing' filesep 'vacuum-full-scan' filesep 'reverse'];

% Length of gas cell [cm]
L_cell = 96.5;

% Extract spectral parameters for data files in each of these folders
[current_gas_fwd f0_gas_fwd A_gas_fwd] = spectrum_analysis(gasfolderfwd);
[current_gas_rev f0_gas_rev A_gas_rev] = spectrum_analysis(gasfolderrev);

% Read spectral parameters for both stage directions, through vacuum
[current_ref_fwd f0_ref_fwd A_ref_fwd] = spectrum_analysis(reffolderfwd);
[current_ref_rev f0_ref_rev A_ref_rev] = spectrum_analysis(reffolderrev);

% Find a linear frequency--current relation from the reference data
% Take an average of the forward and reverse scan so as to avoid any SM hysteresis effects
f0_gas = 0.5 * (f0_gas_fwd + interp1(current_gas_rev, f0_gas_rev, current_gas_fwd, 'spline'));
f0_ref = 0.5 * (f0_ref_fwd + interp1(current_ref_rev, f0_ref_rev, current_ref_fwd, 'spline'));
[m_gas, f0_gas] = Linear_fit(current_gas_fwd, f0_gas);
[m_ref, f0_ref] = Linear_fit(current_ref_fwd, f0_ref);

% Now replace the current tables with the linear frequency fit for each scan direction
f_fit_gas_fwd = m_gas*current_gas_fwd + f0_gas;
f_fit_gas_rev = m_gas*current_gas_rev + f0_gas;
f_fit_ref_fwd = m_ref*current_ref_fwd + f0_ref;
f_fit_ref_rev = m_ref*current_ref_rev + f0_ref;

% Take the average amplitude from the forward and reverse scans to remove hysteresis
A_ref = 0.5 * (A_ref_fwd + interp1(f_fit_ref_rev, A_ref_rev, f_fit_ref_fwd, 'spline'));

% For the gas spectrum, we interpolate everything to fit onto the reference frequency scale
A_gas = 0.5 * (interp1(f_fit_gas_fwd, A_gas_fwd, f_fit_ref_fwd, 'spline') + ...
               interp1(f_fit_gas_rev, A_gas_rev, f_fit_ref_fwd, 'spline'));

% Now use Beer-Lambert law to determine absorption spectrum
alpha = 1/L_cell * log(abs(A_ref ./ A_gas));

% Locate peaks in spectrum
[peak idx] = findpeaks(alpha, 'MinPeakHeight', 1e-3);

fpeak1 = f_fit_ref_fwd(idx(2));
fpeak2 = f_fit_ref_fwd(idx(3));

fprintf('Found peaks (SM) at %f and %f THz\n', fpeak1, fpeak2);

% Load direct-transmission data and calculate absorption spectrum
directscandatafile = ['..' filesep 'direct' filesep 'methanol_absorbance.dat'];
directscandata = load(directscandatafile);
current_direct = directscandata(:,1);
A_gas_direct = directscandata(:,2);
A_ref_direct = directscandata(:,3);

alpha_direct = 1/L_cell * log(A_ref_direct ./ A_gas_direct);
f_direct = f0_ref + m_ref * current_direct;

% Load JPL simulation data
jpldatafile = ['..' filesep 'jpl-data' filesep 'absorption.dat'];
jpldata = load(jpldatafile);
f_jpl = jpldata(:,1)/1000; % Convert to THz
alpha_jpl = jpldata(:,2);

% Locate peaks in spectrum
[peak_jpl idx_jpl] = findpeaks(alpha_jpl, 'MinPeakHeight', 4e-3);

fpeak_jpl1 = f_jpl(idx_jpl(1));
fpeak_jpl2 = f_jpl(idx_jpl(2));

fprintf('Found peaks (JPL) at %f and %f THz\n', fpeak_jpl1, fpeak_jpl2);

% Find fine calibration shift for frequency scale
fshift = 0.5*(fpeak_jpl1 + fpeak_jpl2 - fpeak1 - fpeak2);

fprintf('Peak shift is %f MHz\n', fshift*1e6);

% Shift experimental peaks
f_fit_ref_fwd = f_fit_ref_fwd + fshift;
f_direct      = f_direct      + fshift;

%%%%%%%% Plot Figure 4 %%%%%%%

% Generate figure from data
fig1 = figure;

% Set paper sizing for figure to fit in 1 column, Optics Letters
left   = 0; bottom = 0;
width  = 3; height = 2;
fig1.Units = 'inches';
fig1.Position = [left bottom width height];
fig1.PositionMode = 'manual';
fig1.PaperUnits = 'inches';
fig1.PaperPosition = [left bottom width height];
fig1.PaperSize = [width height];

plot(f_fit_ref_fwd, alpha*1000, 'b-',...
     'LineWidth',      0.5,...
     'DisplayName',    'SM');

hold on;

plot(f_direct, alpha_direct*1000 + 5, 'k-',...
     'LineWidth',      0.5,...
     'DisplayName',    'direct');

plot(f_jpl, alpha_jpl*1000/10 + 10, 'r-',...
     'LineWidth',      0.5,...
     'DisplayName',    'JPL');

legh = legend('show');
legh.FontSize  = 8;
legh.LineWidth = 0.5;
legh.Location  = 'north';

% Set axis properties
ax = gca;
ax.FontName      = 'Times New Roman';
ax.FontUnits     = 'points';
ax.FontSize      = 8;
ax.LineWidth     = 0.5;
ax.XLim          = [3.4039 3.4045];
ax.XLabel.String = 'Frequency (THz)';
ax.YLabel.String = 'Abs. coefficient (10^{-3} cm^{-1})';
ax.YLim          = [-2 30];
ax.YAxis.TickLabelFormat = '%.0f';

print('figure4', '-dpdf', '-r600');
