% Folders containing SM interferograms for vacuum, using sweeps
% in forward and reverse directions
reffolderfwd = '../self-mixing/vacuum/forward';
reffolderrev = '../self-mixing/vacuum/reverse';

% Folders containing SM interferograms for gas at various pressures,
% using sweeps in forward and reverse directions
gas400folderfwd = '../self-mixing/400mTorr/forward';
gas400folderrev = '../self-mixing/400mTorr/reverse';

gas700folderfwd = '../self-mixing/700mTorr/forward';
gas700folderrev = '../self-mixing/700mTorr/reverse';

gas1100folderfwd = '../self-mixing/1100mTorr/forward';
gas1100folderrev = '../self-mixing/1100mTorr/reverse';

% Length of gas cell [cm]
L_cell = 96.5;

% Read spectral parameters for both stage directions, through vacuum
[current_ref_fwd f0_ref_fwd A_ref_fwd] = spectrum_analysis(reffolderfwd);
[current_ref_rev f0_ref_rev A_ref_rev] = spectrum_analysis(reffolderrev);

% And repeat for gas at each pressure
[current_400_fwd  f0_400_fwd  A_400_fwd]  = spectrum_analysis(gas400folderfwd );
[current_400_rev  f0_400_rev  A_400_rev]  = spectrum_analysis(gas400folderrev );
[current_700_fwd  f0_700_fwd  A_700_fwd]  = spectrum_analysis(gas700folderfwd );
[current_700_rev  f0_700_rev  A_700_rev]  = spectrum_analysis(gas700folderrev );
[current_1100_fwd f0_1100_fwd A_1100_fwd] = spectrum_analysis(gas1100folderfwd);
[current_1100_rev f0_1100_rev A_1100_rev] = spectrum_analysis(gas1100folderrev);

% Find a linear frequency--current relation from the reference data
% Take an average of the forward and reverse scan so as to avoid any SM hysteresis effects
f0_ref = 0.5 * (f0_ref_fwd + interp1(current_ref_rev, f0_ref_rev, current_ref_fwd, 'spline'));
[m_ref, f0_ref] = Linear_fit(current_ref_fwd, f0_ref);

% Now replace the current tables with the linear frequency fit for each scan direction
f_fit_ref_fwd = m_ref*current_ref_fwd + f0_ref;
f_fit_ref_rev = m_ref*current_ref_rev + f0_ref;

% Take the average amplitude from the forward and reverse scans to remove hysteresis
A_ref = 0.5 * (A_ref_fwd + interp1(f_fit_ref_rev, A_ref_rev, f_fit_ref_fwd, 'spline'));

% For the gas spectrum, we interpolate everything to fit onto the reference frequency scale
A_400  = 0.5 * (interp1(f_fit_ref_fwd,  A_400_fwd, f_fit_ref_fwd,  'spline') + ...
                interp1(f_fit_ref_rev,  A_400_rev, f_fit_ref_fwd,  'spline'));
A_700  = 0.5 * (interp1(f_fit_ref_fwd,  A_700_fwd, f_fit_ref_fwd,  'spline') + ...
                interp1(f_fit_ref_rev,  A_700_rev, f_fit_ref_fwd,  'spline'));
A_1100 = 0.5 * (interp1(f_fit_ref_fwd, A_1100_fwd, f_fit_ref_fwd, 'spline') + ...
                interp1(f_fit_ref_rev, A_1100_rev, f_fit_ref_fwd, 'spline'));

% Now use Beer-Lambert law to determine absorption spectrum
alpha_400  = 1/L_cell * log(abs(A_ref ./ A_400 ));
alpha_700  = 1/L_cell * log(abs(A_ref ./ A_700 ));
alpha_1100 = 1/L_cell * log(abs(A_ref ./ A_1100));

% Load JPL simulation data
jpldatafile = '../jpl-data/absorption.dat';
jpldata = load(jpldatafile);
f_jpl = jpldata(:,1)/1000; % Convert to THz
alpha_jpl = jpldata(:,2);

% Locate peaks in JPL spectrum
[peak_jpl idx_jpl] = findpeaks(alpha_jpl, 'MinPeakHeight', 4e-3);

fpeak_jpl1 = f_jpl(idx_jpl(1));
fpeak_jpl2 = f_jpl(idx_jpl(2));

% Shift experimental peaks
[peak_400_1  idx_400_1]  = max(alpha_400(1:61));
[peak_700_1  idx_700_1]  = max(alpha_700(1:61));
[peak_1100_1 idx_1100_1] = max(alpha_1100(1:61));
[peak_400_2  idx_400_2]  = max(alpha_400(62:end));
[peak_700_2  idx_700_2]  = max(alpha_700(62:end));
[peak_1100_2 idx_1100_2] = max(alpha_1100(62:end));

fpeak1_400  = f_fit_ref_fwd(idx_400_1 );
fpeak2_400  = f_fit_ref_fwd(idx_400_2 + 61);
fpeak1_700  = f_fit_ref_fwd(idx_700_1 );
fpeak2_700  = f_fit_ref_fwd(idx_700_2 + 61);
fpeak1_1100 = f_fit_ref_fwd(idx_1100_1);
fpeak2_1100 = f_fit_ref_fwd(idx_1100_2 + 61);

fshift_400 = 0.5* (fpeak_jpl1 + fpeak_jpl2 - fpeak1_400  - fpeak2_400 );
fshift_700 = 0.5* (fpeak_jpl1 + fpeak_jpl2 - fpeak1_700  - fpeak2_700 );
fshift_1100 = 0.5*(fpeak_jpl1 + fpeak_jpl2 - fpeak1_1100 - fpeak2_1100);

%%%%%%%%%% Figure 5a %%%%%%%%%%

% Set paper sizing for figure to fit in 1 column, Optics Letters
fig5a = figure;
fig5a.PaperUnits = 'inches';
left   = 0; bottom = 0;
width  = 3; height = 2;
fig5a.PaperPositionMode = 'manual';
fig5a.Units = 'inches';
fig5a.Position = [left bottom width height];
fig5a.PaperPosition = [left bottom width height];
fig5a.PaperSize = [width height];

% Create two axes and set their positions to overlap
ax1 = axes;
ax2 = axes;
ax2.Position = ax1.Position;

linkaxes([ax1 ax2], 'y');
linkprop([ax1 ax2], {'Box',...
                     'FontSize',...
                     'FontUnits',...
                     'FontName',...
                     'LineWidth'});
ax1.Box           = 'on';
ax1.FontName      = 'Times New Roman';
ax1.FontUnits     = 'points';
ax1.FontSize      = 8;
ax1.LineWidth     = 0.5;

ax1_ylabel = ax1.YLabel;
ax2_ylabel = ax1.YLabel;

ax1_xlabel = ax1.XLabel;
ax2_xlabel = ax1.XLabel;

linkprop([ax1_ylabel ax2_ylabel], 'String');
linkprop([ax1_xlabel ax2_xlabel], 'String');

ax1.XLim          = [3.40399 3.40414];
ax1_xlabel.String = 'Frequency (THz)';
ax1_ylabel.String = 'Abs. coefficient (10^{-3} cm^{-1})';
ax1.XAxis.TickLabelFormat = '%.5f';
ax1.YLim          = [-2 15];
ax1.YAxis.TickLabelFormat = '%.0f';
ax1.XTick = [3.40399 3.40404];

ax2.Color = 'none'; % Transparent background
ax2.XLim = [3.40424 3.40439];
ax2.XAxis.TickLabelFormat = '%.5f';
ax2.YAxis.TickLabelFormat = '%.0f';
ax2.XTick = [3.40434 3.40439];

ax2.Position = ax1.Position;

separator = text(1, 0, '//');
separator.Units = 'inches';
separator.Position = [1 0];
separator.FontName = 'Times New Roman';

label = text(1,0, '(a)');
label.Units = 'inches';
label.Position = [0.1 1.3];
label.FontName = 'Times New Roman';

hold(ax1, 'on');

plot(ax1,f_fit_ref_fwd(1:61) + fshift_400, alpha_400(1:61)*1000, 'g-',...
     'LineWidth',   0.5,...
     'DisplayName', '400 mTorr');

plot(ax1,f_fit_ref_fwd(1:61) + fshift_700, alpha_700(1:61)*1000, 'r-',...
     'LineWidth',   0.5,...
     'DisplayName', '700 mTorr');

plot(ax1,f_fit_ref_fwd(1:61) + fshift_1100, alpha_1100(1:61)*1000, 'k-',...
     'LineWidth',   0.5,...
     'DisplayName', '1100 mTorr');

hold(ax1, 'off');
legh = legend('show');
legh.FontSize  = 8;
legh.LineWidth = 0.5;
legh.Location  = 'north';

% Set axis properties
hold(ax2, 'on');
plot(ax2,f_fit_ref_fwd(62:end) + fshift_400, alpha_400(62:end)*1000, 'g-',...
     'LineWidth',   0.5,...
     'DisplayName', '400 mTorr');

plot(ax2,f_fit_ref_fwd(62:end) + fshift_700, alpha_700(62:end)*1000, 'r-',...
     'LineWidth',   0.5,...
     'DisplayName', '700 mTorr');

plot(ax2,f_fit_ref_fwd(62:end) + fshift_1100, alpha_1100(62:end)*1000, 'k-',...
     'LineWidth',   0.5,...
     'DisplayName', '1100 mTorr');

hold(ax2, 'off');

separator = text(1, 0, '//');
separator.Units = 'inches';
separator.Position = [1 0];
separator.FontName = 'Times New Roman';
print('figure5a', '-dpdf', '-r600');

%%%%%% Fig. 5b %%%%%
figb = figure;
figb.PaperUnits = 'inches';
figb.PaperPositionMode = 'manual';
figb.Units = 'inches';
figb.Position = [left bottom width height];
figb.PaperPosition = [left bottom width height];
figb.PaperSize = [width height];

peak1 = [peak_400_1 peak_700_1 peak_1100_1];
peak2 = [peak_400_2 peak_700_2 peak_1100_2];
pressure = [400 700 1100];

% Take a proportional fit to the data
ft = fittype('m*x', 'independent', 'x', 'dependent', 'y');
opts = fitoptions('Method', 'NonLinearLeastSquares');
opts.Display = 'Off';
opts.StartPoint = [0.5e-3];
[x1,y1] = prepareCurveData(pressure, peak1);
[x2,y2] = prepareCurveData(pressure, peak2);
[fitresult_1, gof] = fit(x1, y1, ft, opts);
[fitresult_2, gof] = fit(x2, y2, ft, opts);
m_press_1 = fitresult_1(1);
m_press_2 = fitresult_2(1);

peak1_fit = m_press_1*[0:1100];
peak2_fit = m_press_2*[0:1100];

plot1 = plot(pressure, peak1*1000, 'ko',...
             'LineWidth',   0.5);
hold on;
plot([0:1100], peak1_fit*1000, 'k-',...
     'LineWidth',   0.5);
plot2 = plot(pressure, peak2*1000, 'rx',...
             'LineWidth',   0.5);
plot([0:1100], peak2_fit*1000, 'r-',...
     'LineWidth',   0.5);
     
legh = legend([plot1 plot2], {'Band A', 'Band B'});
legh.FontSize  = 8;
legh.LineWidth = 0.5;
legh.Location  = 'southeast';

% Set axis properties
ax = gca;
ax.FontName      = 'Times New Roman';
ax.FontUnits     = 'points';
ax.FontSize      = 8;
ax.LineWidth     = 0.5;
ax.XLabel.String = 'Pressure (mTorr)';
ax.YLabel.String = 'Abs. coefficient (10^{-3} cm^{-1})';
ax.YAxis.TickLabelFormat = '%.0f';

label = text(1,0, '(b)');
label.Units = 'inches';
label.Position = [0.1 1.3];
label.FontName = 'Times New Roman';

print('figure5b', '-depsc', '-tiff');
