function [f0, A, fwhm, adj_r_square] = gaussian_fit(freq, amp, f_guess, df)
% [f0, A, fwhm, adj_r_square] = GAUSSIAN_FIT(freq, amp, f_guess, df)
% Perform Gaussian fitting to a given spectral data file
%
% Input
%   freq    - Array of frequency samples [THz]
%   amp     - Array of corresponding signal intensity [a.u.]
%   f_guess - Initial estimate of spectral peak frequency [THz]
%   df      - Half-width of range within which to search for peak [THz]
%
% Output
%   f0           - Frequency of spectral peak [THz]
%   A            - Amplitude of spectral peak [a.u.]
%   fwhm         - Full-width at half-max of peak [THz]
%   adj_r_square - Adjusted R-squared fitting error
%
% (c) University of Leeds, 2017

% Set limits for fitting, around the expected peak frequency
f_min = f_guess - df;
f_max = f_guess + df;

% Truncate the search range for Gaussian fitting
fit_window_min=find(freq>f_min, 1);
fit_window_max=find(freq>f_max, 1);

freq_window = freq(fit_window_min:fit_window_max);
amp_window  = amp(fit_window_min:fit_window_max);

% Set up fittype and options:
%  I  is the amplitude
%  w  is width parameter
%  xc is the center frequency
ft = fittype('I*exp(-0.5*((x-xc)/w)^2)',...
             'independent', 'x',...
             'dependent',   'y' );

opts = fitoptions('Method', 'NonlinearLeastSquares');
opts.Algorithm  = 'Trust-Region';
opts.Display    = 'Off';

% Config bounds:  [I    w    xc     ]
%                  -----------------
opts.StartPoint = [1e-5 0.01 f_guess];
opts.Lower      = [0    0    0      ];
opts.Upper      = [1    1    10     ];

opts.MaxIter    = 1000;
opts.TolFun     = 1E-12;

% Fit model to data.
[fitresult, gof] = fit( freq_window', amp_window, ft, opts );

% Extract parameters from the fit
fit_coeff=coeffvalues(fitresult);
sigma = fit_coeff(2);
A     = fit_coeff(1) * sqrt(2*pi) * sigma;  % Amplitude of peak
f0    = fit_coeff(3);  % Centre frequency [THz]

% Find full-width at half-max
fwhm = 2 * sqrt(2 * log(2)) * sigma;  % FWHM [THz]

adj_r_square=gof.rsquare;
end
