function [current, f0, A] = spectrum_analysis(folder)
% SPECTRUM_ANALYSIS(folder)
%   Performs self-mixing spectral analysis on all interferogram data files within a folder.
%
%   Input values:
%     folder - The full path of the folder containing the data files
%
%   Output values:
%     current - Array of all currents obtained from filenames (see below for format)
%     f0      - Array of corresponding peak frequencies obtained from FFTs
%     A       - Array of corresponding FFT amplitudes
%
%   The input files must be named using the format: '<prefix>_<current>mA.dat',
%   where <prefix> is a descriptive name and <current> is the current at which the scan
%   was taken.
%   Note that due to limitations (i.e., a hack!) in the way that the filename parser is written,
%   filenames must not contain the lower-case letter 'm' or the '_' symbol.
%
%   The input files must be in 2-column format containing:
%   * the position of the translation stage in mm (column 1)
%   * the self-mixing voltage in mV (column 2)
%   
%   Two output data files: 'frequency-current.dat' and 'amplitude-current.dat'
%   are created in the target folder, containing the tabulated peak frequencies and
%   amplitudes obtained from the FFT of data file.

freq_current_table_file      = [folder filesep 'frequency-current.dat'];
amplitude_current_table_file = [folder filesep 'amplitude-current.dat'];

% If we've previously run this data analysis, just read the data from existing file
if exist(freq_current_table_file, 'file') == 2
    % Read data from file
    frequency_current = load(freq_current_table_file);
    amplitude_current = load(amplitude_current_table_file);

    % Extract the relevant columns as return values
    current = frequency_current(:,1);
    f0      = frequency_current(:,2);
    A       = amplitude_current(:,2);
else
    % Get a list of all the data files in the folder
    datFiles = dir([folder filesep '*mA.dat']);
    numfiles = length(datFiles);

    % Create arrays to store the output data.
    % Each array element corresponds to a different current sample
    current   = zeros(numfiles, 1);
    f0        = zeros(numfiles, 1);
    f_fitted  = zeros(numfiles, 1);
    A         = zeros(numfiles, 1);
    r_sq      = zeros(numfiles, 1);

    f_guess = 3.405; % An initial estimate of the emission frequency [THz]
    df      = 0.01;  % The bounds within which to search for the peak [THz]

    % The calculation can be slow, so display a progress bar
    progressbar = waitbar(0, 'Starting calculation',...
                          'Name', 'Extracting spectral data');

    % Loop through all the data files and analyse each
    for k = 1:numfiles

        % Get filename
        filename = datFiles(k).name;
        filefullpath = [folder filesep filename];
        
        % Get current from the filename
        fname_parts = strsplit(filename,{'_','m'});
        current(k)  = eval(cell2mat(fname_parts(2)));

        % Update progress bar
        progress = k / numfiles;

        waitbar(progress, progressbar,...
                sprintf('File %d of %d: %f mA', k, numfiles, current(k)),...
                'Name', 'Extracting spectral data');

        % FFT of the Interferogram
        [freq, amp] = fftsmspec_interpolated(filefullpath);

        % Now perform a Gaussian fit to the FFT to find the spectral peak
        [f0(k) A(k) fwhm r_sq(k)] = gaussian_fit(freq, amp, f_guess, df);
    end

    close(progressbar);

    % Save the data tables to files within the folder
    freq_current_table = [current f0];
    save(freq_current_table_file, '-ascii', 'freq_current_table');
    
    amplitude_current_table = [current A];
    save(amplitude_current_table_file, '-ascii', 'amplitude_current_table');
end % if exist
end
